package rpg.arya;

import java.awt.*;
import javax.swing.*;
import java.util.*; // random number generator

public class Npc extends Creature {

	// constants
	private final int GOOD = 0;
	private final int EVIL = 1;
	private final int FRIENDLY = 0;
	private final int UNFRIENDLY = 1;

	private final int MAX_NAMES = 11;
	private final int MAX_FRIENDLY_DESC = 9;
	private final int MAX_UNFRIENDLY_DESC = 10;

	// describes the npc
	private int alignment;
	private int descriptionType;
	private boolean isMarseillesTroops;


	// categorizes npc
	private final int ANIMAL = 0;
	private final int PERSON = 1;
	private final int MONSTER = 2;
	private final int MINION = 3;
	private final int MINIBOSS = 4;
	private int type;

	// ai
	private final int ATTACK = 0;
	private final int FLEE = 1;
	private final int SPECIAL = 2;
	private final int TALK = 3;

	// for character generation
	String names[] = {"Chuckles","Ra","Forest","Crybaby","Thunder",
				      "Hawkeye","Giant","Knuckles", "Rayne","Coco",
				      "Opal"}; // 11;


	String friendly[] = {
	  	"is nurturing plants and stepping over harmless bugs to do so.",
	  	"is pridefully clearing the neighbor's yard of rubble.",
	  	"is reading fairy tales to some orphan children.",
	  	"is helping the cat climb down from the tall tree.",
	   	"is gathering flowers for the ill children.",
	    "is helping an elderly woman across the road.",
	    "is smiling happily at a beautiful butterfly.",
	   	"is joking and laughing genuinely with the villagers.",
	    "is helping a lost child home"};

	String unfriendly [] = {
		"is serving you food while eyeing you suspiciously.",
		"is twitching uncomfortably while approaching you.",
		"is grinding an axe against some stone and leering at you.",
		"is glooming at you from afar.",
		"is impatiently awaiting food.",
	    "is angrily stomping across the neighbor's meticulously planted flowers.",
		"is cruelly laughing at a child who stumbled across a pebble.",
		"is chasing the village's ducklings while laughing maniacally.",
		"is provoking a dog by barking back at it.",
		"is eating heartily while starving children look on."};

	// random number generator initializers
	Random rand;
	int randNum;

	public Npc() {

		alignment = GOOD;
		descriptionType = FRIENDLY;
		type = PERSON;

	 	// random number stuff
		rand = new Random();
		randNum = 0;

		isMarseillesTroops = false;

	}// END of constructor

	// getters
	public int getDescriptionType() {
		return descriptionType;
	}

	public int getAlignment() {
		return alignment;
	}
	public int getType() {
		return type;
	}


	// setters
	public void setDescriptionType(int n) {
		descriptionType = n;
	}
	public void setAlignment(int n) {
		alignment = n;
	}
	public void setType(int n) {
		type = n;
	}


	// method to create or fill values of npc
	public void generateStats() {
	// npcs call this method to initialize themselves

		// assign values to npc fields
		setName(names[randomName()]);

		if (randomBinary() == 0)
			setGender("female");
		else
			setGender("male");

		setAlignment(randomBinary());
		setDescriptionType(randomBinary());

		if (getDescriptionType() == FRIENDLY)
			setDescription(friendly[randomFriendly()]);
		else
			setDescription(unfriendly[randomUnfriendly()]);

		if (!isMarseillesTroops)
			setType(randomType());

		switch (getType()) {
			case ANIMAL: // 1-4
				setLife(randomAnimalAttributes());
				setSpeed(randomAnimalAttributes());
				setOffense(randomAnimalAttributes());
				setDefense(randomAnimalAttributes());
				break;
			case PERSON: // 2-6
				setLife(randomPersonAttributes());
				setSpeed(randomPersonAttributes());
				setOffense(randomPersonAttributes());
				setDefense(randomPersonAttributes());
				break;
			case MONSTER: // 3-7
				setLife(randomPersonAttributes());
				setSpeed(randomPersonAttributes());
				setOffense(randomPersonAttributes());
				setDefense(randomPersonAttributes());
				break;
			case MINION: // 2-5
				setLife(randomMinionAttributes());
				setSpeed(randomMinionAttributes());
				setOffense(randomMinionAttributes());
				setDefense(randomMinionAttributes());
				break;
			case MINIBOSS: // 4-7
				setLife(randomMiniBossAttributes());
				setSpeed(randomMiniBossAttributes());
				setOffense(randomMiniBossAttributes());
				setDefense(randomMiniBossAttributes());
				break;
		}// switch


		setLifePoints();
/*


		weapon.setName();
		weapon.setDescription();
		weapon.setStrength();
		weapon.setSkill();

		armor.setName();
		armor.setDescription();
		armor.setStrength();
		armor.setSkill();

		setOffensive();
		setDefensive();
/*
		calculateChanceToHit();
		calculateChanceToFlee();
		calculateChanceToCounter();
		calculateChanceToDefend();
		calculateCombatInitiative();
*/
	}// END of generateNpc

	// methods to generate random numbers for npc
	public int randomName() {
		randNum = rand.nextInt(MAX_NAMES);
		return randNum;
	}// randomName()

	public int randomBinary() {
		randNum = rand.nextInt(2);
		return randNum;
	}// randomBinary()

	public int randomFriendly() {
		randNum = rand.nextInt(MAX_FRIENDLY_DESC);
		return randNum;
	}// randomFriendly()

	public int randomUnfriendly() {
		randNum = rand.nextInt(MAX_UNFRIENDLY_DESC);
		return randNum;
	}// randomUnfriendly()

	public int randomType() {
			randNum = rand.nextInt(3);
			return randNum;
	}// randomType()

	public int randomAnimalAttributes() {
				randNum = rand.nextInt(4)+1;
				return randNum;
	}// Animal Attributes

	public int randomPersonAttributes() {
					randNum = rand.nextInt(5)+2;
					return randNum;
	}// Person Attributes

	public int randomMonsterAttributes() {
		randNum = rand.nextInt(5)+3;
		return randNum;
	}// Monster Attributes


	public int randomMinionAttributes() {
		randNum = rand.nextInt(4)+2;
		return randNum;
	}// Monster Attributes

	public int randomMiniBossAttributes() {
			randNum = rand.nextInt(4)+4;
			return randNum;
	}// Monster Attributes


}// END of Npc